
<div class="list-container">
    <div class="table-wrapper">
        <nz-table
            #eventsTable
            [nzData]="events"
            [nzLoading]="isDataLoading"
            [nzPageSize]="20"
            nzPaginationPosition="top"
            nzShowSizeChanger="true"
            nzSize="small"
        >
            <thead>
                <tr>
                    <th>Date&nbsp;&nbsp;&nbsp;&nbsp;(Loaded {{events.length}})</th>
                    <th *ngFor="let prop of displayProps" [nzShowSort]="false">
                        {{ prop.name }}
                    </th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody *ngFor="let event of eventsTable.data">
                <tr [ngStyle]="{'background-color': colorValue(event)}">
                    <td>
                        <div class="date-cell">
                            <span class="date-time">{{ event.dateTime | date:'HH:mm:ss.SSS' }}</span>
                            <span class="date-time">{{ event.dateTime | date:'dd-MMM-yyyy' }}</span>
                        </div>
                    </td>
                    <td *ngFor="let prop of displayProps">
                        {{displayValue(event, prop)}}
                    </td>
                    <td>
                        <div class="action-cell">
                            <a (click)="handleInfoClick($event, event)">Info</a>
                        </div>
                    </td>
                </tr>
            </tbody>
        </nz-table>
    </div>
</div>